@@ -35,9 +35,9 @@ static ServiceRole services[] = {
 	{ "acpid",                  GST_ROLE_POWER_MANAGEMENT },
 	{ "alsa",                   GST_ROLE_AUDIO_MANAGEMENT },
 	{ "alsa-utils",             GST_ROLE_AUDIO_MANAGEMENT },
+	{ "am-utils",               GST_ROLE_AUTOMOUNTER },
 	{ "amavis",                 GST_ROLE_ANTIVIRUS },
 	{ "amavis-ng",              GST_ROLE_ANTIVIRUS },
-	{ "am-utils",               GST_ROLE_AUTOMOUNTER },
 	{ "anacron",                GST_ROLE_COMMAND_SCHEDULER },
 	{ "apache",                 GST_ROLE_WEB_SERVER },
 	{ "apache-perl",            GST_ROLE_WEB_SERVER },
@@ -52,8 +52,8 @@ static ServiceRole services[] = {
 	{ "autofs",                 GST_ROLE_AUTOMOUNTER },
 	{ "avahi-daemon",           GST_ROLE_RENDEZVOUS },
 	{ "backuppc",               GST_ROLE_REMOTE_BACKUP },
-	{ "bind9",                  GST_ROLE_DNS },
 	{ "bind",                   GST_ROLE_DNS },
+	{ "bind9",                  GST_ROLE_DNS },
 	{ "bluetooth",              GST_ROLE_BLUETOOTH_MANAGEMENT },
 	{ "bpalogin",               GST_ROLE_TELSTRA_BIGPOND_NETWORK_CLIENT },
 	{ "brltty",                 GST_ROLE_BRAILLE_DISPLAY_MANAGEMENT },
@@ -65,8 +65,9 @@ static ServiceRole services[] = {
 	{ "courier",                GST_ROLE_MTA },
 	{ "courier-authdaemon",     GST_ROLE_MTA_AUTH },
 	{ "courier-mta",            GST_ROLE_MTA },
-	{ "crond",                  GST_ROLE_COMMAND_SCHEDULER },
 	{ "cron",                   GST_ROLE_COMMAND_SCHEDULER },
+	{ "crond",                  GST_ROLE_COMMAND_SCHEDULER },
+	{ "cups",                   GST_ROLE_PRINTER_SERVICE },
 	{ "cupsd",                  GST_ROLE_PRINTER_SERVICE },
 	{ "cupsys",                 GST_ROLE_PRINTER_SERVICE },
 	{ "dbus",                   GST_ROLE_DBUS },
@@ -78,15 +79,15 @@ static ServiceRole services[] = {
 	{ "eagle-usb",              GST_ROLE_EAGLE_USB_MODEMS_MANAGEMENT },
 	{ "etc-setserial",          GST_ROLE_SERIAL_PORTS_MANAGEMENT },
 	{ "evms",                   GST_ROLE_LVM_MANAGEMENT },
-	{ "exim4",                  GST_ROLE_MTA },
 	{ "exim",                   GST_ROLE_MTA },
+	{ "exim4",                  GST_ROLE_MTA },
 	{ "fcron",                  GST_ROLE_COMMAND_SCHEDULER },
 	{ "festival",               GST_ROLE_SPEECH_SYNTHESIS },
 	{ "fetchmail",              GST_ROLE_MAIL_FETCHER },
 	{ "ftpd",                   GST_ROLE_FILE_SERVER_FTP },
 	{ "gdm",                    GST_ROLE_DISPLAY_MANAGER },
-	{ "gfs2-tools",             GST_ROLE_CLUSTER_MANAGEMENT },
 	{ "gfs-tools",              GST_ROLE_CLUSTER_MANAGEMENT },
+	{ "gfs2-tools",             GST_ROLE_CLUSTER_MANAGEMENT },
 	{ "gnbd-client",            GST_ROLE_CLUSTER_MANAGEMENT },
 	{ "gnbd-server",            GST_ROLE_CLUSTER_MANAGEMENT },
 	{ "hdparm",                 GST_ROLE_HDD_MANAGEMENT },
@@ -104,6 +105,7 @@ static ServiceRole services[] = {
 	{ "kdm",                    GST_ROLE_DISPLAY_MANAGER },
 	{ "keepalived",             GST_ROLE_CLUSTER_MANAGEMENT },
 	{ "klogd",                  GST_ROLE_SYSTEM_LOGGER },
+	{ "lighttpd",               GST_ROLE_WEB_SERVER },
 	{ "lm-sensors",             GST_ROLE_HARDWARE_MONITORING },
 	{ "lpd",                    GST_ROLE_PRINTER_SERVICE },
 	{ "lpdng",                  GST_ROLE_PRINTER_SERVICE },
@@ -146,6 +148,10 @@ static ServiceRole services[] = {
 	{ "postgresql-8.0",         GST_ROLE_DATABASE_SERVER },
 	{ "postgresql-8.1",         GST_ROLE_DATABASE_SERVER },
 	{ "postgresql-8.2",         GST_ROLE_DATABASE_SERVER },
+	{ "postgresql-8.3",         GST_ROLE_DATABASE_SERVER },
+	{ "postgresql-8.4",         GST_ROLE_DATABASE_SERVER },
+	{ "postgresql-8.5",         GST_ROLE_DATABASE_SERVER },
+	{ "postgresql-9.0",         GST_ROLE_DATABASE_SERVER },
 	{ "powernowd",              GST_ROLE_CPUFREQ_MANAGEMENT },
 	{ "pptpd",                  GST_ROLE_VPN_SERVER },
 	{ "proftpd",                GST_ROLE_FILE_SERVER_FTP },
@@ -156,8 +162,8 @@ static ServiceRole services[] = {
 	{ "racoon",                 GST_ROLE_IPSEC_KEY_EXCHANGE_SERVER },
 	{ "radvd",                  GST_ROLE_ROUTER_ADVERTISEMENT_SERVER },
 	{ "rgmanager",              GST_ROLE_CLUSTER_MANAGEMENT },
-	{ "rsyncd",                 GST_ROLE_REMOTE_BACKUP },
 	{ "rsync",                  GST_ROLE_REMOTE_BACKUP },
+	{ "rsyncd",                 GST_ROLE_REMOTE_BACKUP },
 	{ "samba",                  GST_ROLE_FILE_SERVER_SMB },
 	{ "schoolbell",             GST_ROLE_WEB_CALENDAR_SERVER },
 	{ "schooltool",             GST_ROLE_SCHOOL_MANAGEMENT_PLATFORM },
@@ -176,6 +182,7 @@ static ServiceRole services[] = {
 	{ "syslog",                 GST_ROLE_SYSTEM_LOGGER },
 	{ "tftpd-hpa",              GST_ROLE_FILE_SERVER_TFTP },
 	{ "vcron",                  GST_ROLE_COMMAND_SCHEDULER },
+	{ "vmware-player",          GST_ROLE_VIRTUAL_MACHINE_MANAGEMENT },
 	{ "vsftpd",                 GST_ROLE_FILE_SERVER_FTP },
 	{ "wacom-tools",            GST_ROLE_GRAPHIC_TABLETS_MANAGEMENT },
 	{ "wdm",                    GST_ROLE_DISPLAY_MANAGER },
