@@ -58,6 +58,9 @@ struct _GstTool {
 
 	GtkIconTheme *icon_theme;
 	GstDialog *main_dialog;
+	GtkWidget *configuration_changed_dialog;
+
+	time_t last_commit_time;
 
 	/* Progress report widgets */
 	GtkWidget *report_window;
